@@ -659,13 +659,14 @@ class Say(Node):
             rv.append("id")
             rv.append(getattr(self, "identifier", None))
 
+        if self.arguments:
+            rv.append(self.arguments.get_code())
+
+        # This has to be at the end.
         if self.with_:
             rv.append("with")
             rv.append(self.with_)
 
-        if self.arguments:
-            rv.append(self.arguments.get_code())
-
         return " ".join(rv)
 
     def execute(self):
@@ -700,8 +701,8 @@ class Say(Node):
             if self.arguments is not None:
                 args, kwargs = self.arguments.evaluate()
             else:
-                args = tuple()
-                kwargs = dict()
+                args = ()
+                kwargs = {}
 
             kwargs.setdefault("interact", self.interact)
 
@@ -1239,6 +1240,46 @@ class ShowLayer(Node):
             self.atl.mark_constant()
 
 
+class Camera(Node):
+
+    warp = True
+
+    __slots__ = [
+        'layer',
+        'at_list',
+        'atl',
+        ]
+
+    def __init__(self, loc, layer, at_list, atl):
+        super(Camera, self).__init__(loc)
+
+        self.layer = layer
+        self.at_list = at_list
+        self.atl = atl
+
+    def diff_info(self):
+        return (ShowLayer, self.layer)
+
+    def execute(self):
+        next_node(self.next)
+        statement_name("show layer")
+
+        at_list = [ renpy.python.py_eval(i) for i in self.at_list ]
+
+        if self.atl is not None:
+            atl = renpy.display.motion.ATLTransform(self.atl)
+            at_list.append(atl)
+
+        renpy.exports.layer_at_list(at_list, layer=self.layer, camera=True)
+
+    def predict(self):
+        return [ self.next ]
+
+    def analyze(self):
+        if self.atl is not None:
+            self.atl.mark_constant()
+
+
 class Scene(Node):
 
     __slots__ = [
@@ -1632,7 +1673,7 @@ class Menu(Node):
                 if self.item_arguments and (self.item_arguments[i] is not None):
                     item_arguments.append(self.item_arguments[i].evaluate())
                 else:
-                    item_arguments.append((tuple(), dict()))
+                    item_arguments.append(((), {}))
 
         if narration:
             renpy.exports.say(None, "\n".join(narration), interact=False)
@@ -2061,6 +2102,7 @@ def create_store(name):
 
 
 class StoreNamespace(object):
+    pure = True
 
     def __init__(self, store):
         self.store = store
@@ -2159,7 +2201,9 @@ class Define(Node):
             renpy.dump.definitions.append((self.store[6:] + "." + self.varname, self.filename, self.linenumber))
 
         if self.operator == "=" and self.index is None:
-            renpy.exports.pure(self.store + "." + self.varname)
+            ns, _special = get_namespace(self.store)
+            if getattr(ns, "pure", True):
+                renpy.exports.pure(self.store + "." + self.varname)
 
         self.set()
 
